==> kendo-ui-2023.2.606.tgz: package/js/kendo.ui.core.js <==
require('./kendo.core.js');
require('./kendo.router.js');
require('./kendo.touch.js');
require('./kendo.view.js');
require('./kendo.floatinglabel.js');
require('./kendo.label.js');
require('./kendo.fx.js');
require('./kendo.data.odata.js');
require('./kendo.data.xml.js');
require('./kendo.data.js');
require('./kendo.data.signalr.js');
require('./kendo.binder.js');
require('./kendo.validator.js');
require('./kendo.userevents.js');
require('./kendo.draganddrop.js');
require('./kendo.mobile.scroller.js');
require('./kendo.resizable.js');
require('./kendo.sortable.js');
require('./kendo.selectable.js');
require('./kendo.badge.js');
require('./kendo.button.js');
require('./kendo.buttongroup.js');
require('./kendo.bottomnavigation.js');
require('./kendo.pager.js');
require('./kendo.popup.js');
require('./kendo.actionsheet.js');
require('./kendo.notification.js');
require('./kendo.tooltip.js');
require('./kendo.splitbutton.js');
require('./kendo.dropdownbutton.js');
require('./kendo.toolbar.js');
require('./kendo.list.js');
require('./kendo.calendar.js');
require('./kendo.autocomplete.js');
require('./kendo.dropdownlist.js');
require('./kendo.combobox.js');
require('./kendo.multiselect.js');
require('./kendo.colorpicker.js');
require('./kendo.listbox.js');
require('./kendo.loader.js');
require('./kendo.textbox.js');
require('./kendo.textarea.js');
require('./kendo.numerictextbox.js');
require('./kendo.maskedtextbox.js');
require('./kendo.menu.js');
require('./kendo.panelbar.js');
require('./kendo.progressbar.js');
require('./kendo.responsivepanel.js');
require('./kendo.tabstrip.js');
require('./kendo.slider.js');
require('./kendo.splitter.js');
require('./kendo.dialog.js');
require('./kendo.window.js');
require('./kendo.virtuallist.js');
require('./kendo.togglebutton.js');
require('./kendo.icons.js');
require('./kendo.mobile.popover.js');
require('./kendo.mobile.loader.js');
require('./kendo.mobile.shim.js');
require('./kendo.mobile.view.js');
require('./kendo.mobile.modalview.js');
require('./kendo.mobile.drawer.js');
require('./kendo.mobile.splitview.js');
require('./kendo.mobile.pane.js');
require('./kendo.mobile.application.js');
require('./kendo.mobile.actionsheet.js');
require('./kendo.mobile.button.js');
require('./kendo.mobile.buttongroup.js');
require('./kendo.mobile.collapsible.js');
require('./kendo.mobile.listview.js');
require('./kendo.mobile.navbar.js');
require('./kendo.mobile.scrollview.js');
require('./kendo.mobile.switch.js');
require('./kendo.mobile.tabstrip.js');
require('./kendo.angular.js');

"bundle all";

==> kendo-ui-2025.1.227.tgz: package/js/kendo.ui.core.js <==
'use strict';

require('./kendo.core.js');
require('./kendo.router.js');
require('./kendo.touch.js');
require('./kendo.view.js');
require('./kendo.floatinglabel.js');
require('./kendo.label.js');
require('./kendo.fx.js');
require('./kendo.data.odata.js');
require('./kendo.data.xml.js');
require('./kendo.data.js');
require('./kendo.data.signalr.js');
require('./kendo.binder.js');
require('./kendo.validator.js');
require('./kendo.userevents.js');
require('./kendo.draganddrop.js');
require('./kendo.mobile.scroller.js');
require('./kendo.resizable.js');
require('./kendo.sortable.js');
require('./kendo.selectable.js');
require('./kendo.badge.js');
require('./kendo.button.js');
require('./kendo.buttongroup.js');
require('./kendo.bottomnavigation.js');
require('./kendo.pager.js');
require('./kendo.popup.js');
require('./kendo.actionsheet.js');
require('./kendo.notification.js');
require('./kendo.tooltip.js');
require('./kendo.splitbutton.js');
require('./kendo.dropdownbutton.js');
require('./kendo.toolbar.js');
require('./kendo.list.js');
require('./kendo.calendar.js');
require('./kendo.autocomplete.js');
require('./kendo.dropdownlist.js');
require('./kendo.combobox.js');
require('./kendo.multiselect.js');
require('./kendo.colorpicker.js');
require('./kendo.listbox.js');
require('./kendo.loader.js');
require('./kendo.textbox.js');
require('./kendo.textarea.js');
require('./kendo.numerictextbox.js');
require('./kendo.maskedtextbox.js');
require('./kendo.menu.js');
require('./kendo.panelbar.js');
require('./kendo.progressbar.js');
require('./kendo.responsivepanel.js');
require('./kendo.tabstrip.js');
require('./kendo.slider.js');
require('./kendo.splitter.js');
require('./kendo.dialog.js');
require('./kendo.window.js');
require('./kendo.virtuallist.js');
require('./kendo.togglebutton.js');
require('./kendo.icons.js');
require('./kendo.licensing.js');
require('@progress/kendo-licensing');
require('./kendo.html.icon.js');
require('./kendo.html.base.js');
require('@progress/kendo-svg-icons');
require('./kendo.html.button.js');
require('./dropdowns-loader-Bc4IELFi.js');
require('./valueMapper-q_OtZ-Tj.js');
require('./kendo.button.menu.js');
require('./prefix-suffix-containers-BmDm564f.js');
require('./kendo.html.chip.js');
require('./kendo.html.chiplist.js');
require('./kendo.color.js');
require('@progress/kendo-drawing');

var kendo$1 = kendo;

module.exports = kendo$1;
